@@ -173,34 +173,34 @@ class CloudFrontToMediaStore(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontOriginRequestPolicy")
     def cloud_front_origin_request_policy(
         self,
     ) -> aws_cdk.aws_cloudfront.OriginRequestPolicy:
         return typing.cast(aws_cdk.aws_cloudfront.OriginRequestPolicy, jsii.get(self, "cloudFrontOriginRequestPolicy"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="mediaStoreContainer")
     def media_store_container(self) -> aws_cdk.aws_mediastore.CfnContainer:
         return typing.cast(aws_cdk.aws_mediastore.CfnContainer, jsii.get(self, "mediaStoreContainer"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontFunction")
     def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
         return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudFrontOriginAccessIdentity")
     def cloud_front_origin_access_identity(
         self,
@@ -239,9 +239,9 @@ class CloudFrontToMediaStoreProps:
         :summary: The properties for the CloudFrontToMediaStore Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(media_store_container_props, dict):
-            media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
+            media_store_container_props = CfnContainerProps(**media_store_container_props)
         if __debug__:
             type_hints = typing.get_type_hints(CloudFrontToMediaStoreProps.__init__)
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
